pub struct GenericValues {Show 17 fields
pub app_name: String,
pub startup_type: String,
pub server_host: Option<String>,
pub server_port: Option<u16>,
pub acme_domain: Option<String>,
pub ssl_key_path: Option<String>,
pub ssl_crt_path: Option<String>,
pub auto_migrate_bin: Option<String>,
pub server_port_achiever: Option<PathBuf>,
pub allow_cors_domain: Option<String>,
pub allow_oapi_access: Option<bool>,
pub oapi_frontend_type: Option<String>,
pub oapi_name: Option<String>,
pub oapi_ver: Option<String>,
pub oapi_api_addr: Option<String>,
pub security_headers: SecurityHeadersOptions,
pub tracing_options: TracingOptions,
}Expand description
Server generic configuration.
Fields
app_name: StringApplication name.
You’re not needed to write it in YAML configuration, instead you should send it to load_generic_config function.
startup_type: StringStartup variant. Converts to StartupVariant.
server_host: Option<String>Server host.
server_port: Option<u16>Server port. For no reverse proxy and Internet usage, set to 80 for HTTP and 443 for HTTPS/QUIC.
acme_domain: Option<String>ACME origin; see salvo/conn/acme docs.
ssl_key_path: Option<String>Path to SSL key.
ssl_crt_path: Option<String>Path to SSL certificate.
auto_migrate_bin: Option<String>If you want to run any migration or anything else just before server’s start, set to path to binary.
server_port_achiever: Option<PathBuf>Use text file to find out which port to listen to.
allow_cors_domain: Option<String>CORS allowed domains
allow_oapi_access: Option<bool>Set this to true to enable OpenAPI endpoint.
oapi_frontend_type: Option<String>Select Scalar or SwaggerUI.
oapi_name: Option<String>By default, equals app_name; consider give expanded API name.
oapi_ver: Option<String>API version.
oapi_api_addr: Option<String>API endpoint (with slash), e.g. /api or /swagger.
security_headers: SecurityHeadersOptionsSecurity response headers applied to every response when the
router is built via get_root_router_autoinject. See
crate::security_headers::SecurityHeadersOptions.
tracing_options: TracingOptionsTracing options