pub struct TracingOptions {Show 16 fields
pub enable_io_logs: Option<bool>,
pub io_log_level: Option<String>,
pub enable_file_logs: Option<bool>,
pub file_log_level: Option<String>,
pub file_log_rotation: Option<String>,
pub file_log_max_rolling_files: Option<u32>,
pub enable_syslog_logs: Option<bool>,
pub syslog_addr: Option<String>,
pub syslog_log_level: Option<String>,
pub enable_ecs_logs: Option<bool>,
pub ecs_log_level: Option<String>,
pub ecs_rotation: Option<String>,
pub ecs_max_rolling_files: Option<u32>,
pub otel_grpc_endpoint: Option<String>,
pub otel_http_endpoint: Option<String>,
pub otel_log_level: Option<String>,
}Expand description
Tracing options.
Fields
enable_io_logs: Option<bool>Enable I/O logs.
io_log_level: Option<String>Log level; for no logging delete the line in YAML completely.
enable_file_logs: Option<bool>Enable file logs.
file_log_level: Option<String>File’s log level. Defaults to log_level.
file_log_rotation: Option<String>File rolling rotation, if you have a ton of logs and need to split them.
file_log_max_rolling_files: Option<u32>Files limitation for autoremove.
enable_syslog_logs: Option<bool>Enable RFC 5424 logging.
syslog_addr: Option<String>Address to send logs via TCP/UDP or into UNIX sockets.
syslog_log_level: Option<String>Syslog’s log level. Defaults to log_level.
enable_ecs_logs: Option<bool>Enable Elastic Common Schema structured logging.
ecs_log_level: Option<String>ECS log level. Defaults to log_level.
ecs_rotation: Option<String>ECS rolling rotation, if you have a ton of ECS logs and need to split them.
ecs_max_rolling_files: Option<u32>ECS files limitation for autoremove.
otel_grpc_endpoint: Option<String>Endpoint to export OpenTelemetry via gRPC (e.g., Jaeger).
otel_http_endpoint: Option<String>Endpoint to export OpenTelemetry via HTTP binary protocol (e.g., Prometheus).
otel_log_level: Option<String>OpenTelemetry log level. Defaults to log_level.
Implementations
Sourceimpl TracingOptions
impl TracingOptions
Sourcepub fn init(&self, app_name: &str) -> MResult<TracingGuards>
pub fn init(&self, app_name: &str) -> MResult<TracingGuards>
Inits logging application-wide.